@@ -1,7 +1,7 @@
 __title__ = 'slim.defaults'
-__version__ = '0.7'
-__build__ = 0x000007
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = 'Copyright (c) 2013-2014 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('USE_LOCALEURL', 'USE_LOCAL_LANGUAGE_NAMES', 'ENABLE_MONKEY_PATCHING')
 
 # If set to False, `django-localeurl` usage in `slim` is force-disabled.
