@@ -1,7 +1,7 @@
 __title__ = 'slim.models.decorators'
-__version__ = '0.7'
-__build__ = 0x000007
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__copyright__ = 'Copyright (c) 2013-2014 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('prepend_language', 'localeurl_prepend_language', 'auto_prepend_language')
 
 from slim.utils import locale_url_is_installed
